#!/usr/bin/env node
"use strict";
/**
 * CodeContext Pro CLI - Premium Version
 *
 * The AI cognitive revolution starts here.
 * $99/month for the first 10,000 early adopters.
 * Then $199/month forever.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const chalk_1 = __importDefault(require("chalk"));
const MemoryEngine_1 = require("./memory/MemoryEngine");
const ProjectScanner_1 = require("./memory/ProjectScanner");
const vscode_setup_1 = require("./integrations/vscode-setup");
const LicenseService_1 = require("./services/LicenseService");
const FirebaseService_1 = require("./services/FirebaseService");
const packageJson = __importStar(require("../package.json"));
const program = new commander_1.Command();
program
    .name('codecontext')
    .description('🧠 AI Memory Revolution - Stop AI amnesia forever')
    .version(packageJson.version)
    .addHelpText('before', `
${chalk_1.default.bold.cyan('🧠 CodeContext Pro - AI Cognitive Upgrade')}

${chalk_1.default.yellow('🔥 EARLY ADOPTER SPECIAL: $99/month (Limited to 10,000 licenses)')}
${chalk_1.default.yellow('📈 After 10,000 sold: $199/month forever')}

This is the most powerful AI productivity tool ever created.
Your AI assistant will remember EVERYTHING and execute code in real-time.
  `);
// Purchase command
program
    .command('purchase')
    .description('🔥 Purchase your CodeContext Pro license')
    .argument('<email>', 'Your email address')
    .action(async (email) => {
    try {
        console.log(chalk_1.default.bold.cyan('\n🧠 Welcome to the AI Memory Revolution!\n'));
        const licenseKey = await LicenseService_1.licenseService.purchaseLicense(email);
        console.log(chalk_1.default.green('\n🎉 Purchase successful!'));
        console.log(chalk_1.default.blue(`\nNext step: codecontext activate ${email} ${licenseKey}`));
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Purchase failed:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// Activate command
program
    .command('activate')
    .description('🚀 Activate your CodeContext Pro license')
    .argument('<email>', 'Your email address')
    .argument('<license-key>', 'Your license key')
    .action(async (email, licenseKey) => {
    try {
        await LicenseService_1.licenseService.activateLicense(email, licenseKey);
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Activation failed:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// License status
program
    .command('license')
    .description('📊 Show license status')
    .action(async () => {
    try {
        await LicenseService_1.licenseService.showLicenseStatus();
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to get license status:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// Protected commands (require license)
async function requireLicense() {
    const license = await LicenseService_1.licenseService.getCurrentLicense();
    if (!license) {
        console.log(chalk_1.default.red(`
🔒 LICENSE REQUIRED

This feature requires CodeContext Pro.

🔥 Early Adopter Special: $99/month  
📈 After 10,000 licenses: $199/month

Purchase now: codecontext purchase your@email.com
    `));
        process.exit(1);
    }
    return license;
}
program
    .command('init')
    .description('🧠 Initialize AI memory for current project')
    .option('-f, --force', 'Force reinitialize existing project')
    .action(async (options) => {
    try {
        await requireLicense();
        await LicenseService_1.licenseService.validateFeatureAccess('persistentMemory');
        const memory = new MemoryEngine_1.MemoryEngine();
        await memory.initProject(process.cwd(), options.force);
        // Report usage
        await FirebaseService_1.firebaseService.reportUsage('project_init', {
            projectPath: process.cwd(),
            forced: options.force
        });
        console.log(chalk_1.default.green('🧠 AI Memory initialized! Your assistant will remember EVERYTHING.'));
        console.log(chalk_1.default.blue('💡 Run "codecontext status" to see memory state'));
        console.log(chalk_1.default.blue('💡 Run "codecontext scan --deep" for advanced analysis'));
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to initialize:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('status')
    .description('📊 Show AI memory status')
    .action(async () => {
    try {
        await requireLicense();
        const memory = new MemoryEngine_1.MemoryEngine();
        const status = await memory.getProjectStatus(process.cwd());
        console.log(chalk_1.default.bold('\n🧠 CodeContext Pro - AI Memory Status\n'));
        console.log(`📂 Project: ${chalk_1.default.cyan(status.projectName)}`);
        console.log(`🆔 ID: ${status.projectId}`);
        console.log(`📅 Created: ${status.createdAt.toLocaleString()}`);
        console.log(`🕐 Last Active: ${status.lastActive.toLocaleString()}`);
        console.log(`📁 Files Tracked: ${chalk_1.default.yellow(status.filesTracked.toString())}`);
        console.log(`💬 Conversations: ${chalk_1.default.yellow(status.conversations.toString())}`);
        console.log(`🧩 Patterns: ${chalk_1.default.yellow(status.patterns.toString())}`);
        console.log(`📊 Memory Size: ${status.memorySize}`);
        if (status.recentActivity.length > 0) {
            console.log(chalk_1.default.bold('\n📈 Recent Activity:'));
            status.recentActivity.forEach(activity => {
                console.log(`  • ${activity.timestamp.toLocaleString()}: ${activity.description}`);
            });
        }
        await FirebaseService_1.firebaseService.reportUsage('status_check');
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to get status:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('scan')
    .description('🔍 Scan and analyze project with AI')
    .option('-d, --deep', 'Perform deep AI analysis')
    .action(async (options) => {
    try {
        await requireLicense();
        const memory = new MemoryEngine_1.MemoryEngine();
        const scanner = new ProjectScanner_1.ProjectScanner();
        console.log(chalk_1.default.blue('🔍 Scanning project with AI intelligence...'));
        const analysis = await scanner.scanProject(process.cwd(), options.deep);
        await memory.storeProjectAnalysis(process.cwd(), analysis);
        console.log(chalk_1.default.green(`✅ AI analyzed ${analysis.files.length} files`));
        console.log(chalk_1.default.blue(`🧩 Discovered ${analysis.patterns.length} code patterns`));
        console.log(chalk_1.default.blue(`🏗️ Detected ${analysis.architecture.frameworks.length} frameworks`));
        await FirebaseService_1.firebaseService.reportUsage('project_scan', {
            filesScanned: analysis.files.length,
            patternsFound: analysis.patterns.length,
            deepScan: options.deep
        });
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to scan:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('remember')
    .description('🧠 Store memory for AI assistant')
    .argument('<content>', 'What to remember')
    .option('-t, --type <type>', 'Memory type (conversation, decision, pattern)', 'conversation')
    .option('-c, --context <context>', 'Additional context')
    .action(async (content, options) => {
    try {
        await requireLicense();
        await LicenseService_1.licenseService.validateFeatureAccess('persistentMemory');
        const memory = new MemoryEngine_1.MemoryEngine();
        await memory.storeMemory(process.cwd(), {
            type: options.type,
            content,
            context: options.context,
            timestamp: new Date()
        });
        // Sync to cloud
        await FirebaseService_1.firebaseService.reportUsage('memory_store', {
            type: options.type,
            contentLength: content.length
        });
        console.log(chalk_1.default.green('🧠 Memory stored! AI will remember this forever.'));
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to store memory:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('execute')
    .description('⚡ Execute and verify code with AI')
    .argument('<code-file>', 'Code file to execute')
    .option('-l, --language <lang>', 'Programming language')
    .action(async (codeFile, options) => {
    try {
        await requireLicense();
        await LicenseService_1.licenseService.validateFeatureAccess('executionEngine');
        const fs = require('fs-extra');
        const code = await fs.readFile(codeFile, 'utf8');
        console.log(chalk_1.default.blue('⚡ Executing code in secure cloud environment...'));
        const result = await FirebaseService_1.firebaseService.validateExecution(code, options.language || 'javascript', { projectPath: process.cwd() });
        if (result.success) {
            console.log(chalk_1.default.green('✅ Code executed successfully!'));
            console.log(chalk_1.default.blue(`Output: ${result.output}`));
            console.log(chalk_1.default.gray(`Time: ${result.executionTime}ms, Memory: ${result.memoryUsed} bytes`));
        }
        else {
            console.log(chalk_1.default.red('❌ Code execution failed!'));
            console.log(chalk_1.default.red(`Error: ${result.error}`));
        }
        await FirebaseService_1.firebaseService.reportUsage('code_execution', {
            language: options.language,
            success: result.success,
            executionTime: result.executionTime
        });
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Execution failed:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('sync')
    .description('☁️ Sync memory to cloud')
    .action(async () => {
    try {
        await requireLicense();
        await LicenseService_1.licenseService.validateFeatureAccess('cloudSync');
        console.log(chalk_1.default.blue('☁️ Syncing memory to cloud...'));
        // Implementation would sync local memory to Firebase
        console.log(chalk_1.default.green('✅ Memory synced to cloud!'));
        await FirebaseService_1.firebaseService.reportUsage('cloud_sync');
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Sync failed:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// VS Code integration (premium feature)
program
    .command('vscode')
    .description('🔧 Set up VS Code integration')
    .action(async () => {
    try {
        await requireLicense();
        await (0, vscode_setup_1.setupVSCode)(process.cwd());
        console.log(chalk_1.default.green('✅ VS Code integration configured!'));
        console.log(chalk_1.default.blue('💡 Restart VS Code to activate premium features'));
        await FirebaseService_1.firebaseService.reportUsage('vscode_setup');
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to set up VS Code:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// Show help if no command provided
program.parse();
if (!process.argv.slice(2).length) {
    console.log(chalk_1.default.bold.cyan('\n🧠 CodeContext Pro - AI Memory Revolution\n'));
    console.log(chalk_1.default.yellow('🔥 EARLY ADOPTER SPECIAL: $99/month (Limited to 10,000 licenses)'));
    console.log(chalk_1.default.yellow('📈 After 10,000 sold: $199/month forever\n'));
    program.outputHelp();
    console.log(chalk_1.default.blue('\n💡 Get started:'));
    console.log(chalk_1.default.blue('   codecontext purchase your@email.com'));
    console.log(chalk_1.default.blue('   codecontext activate your@email.com YOUR-LICENSE-KEY'));
    console.log(chalk_1.default.blue('   codecontext init'));
    console.log(chalk_1.default.gray('\n💰 This cognitive upgrade pays for itself in 1 day.'));
    console.log(chalk_1.default.gray('🚀 Join the AI memory revolution!'));
}
//# sourceMappingURL=cli-premium.js.map