"use strict";
/**
 * VS Code Setup - Configure integration without extension
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupVSCode = setupVSCode;
const path = __importStar(require("path"));
const fs = __importStar(require("fs-extra"));
const os = __importStar(require("os"));
async function setupVSCode(projectPath) {
    // Create .vscode directory in project
    const vscodeDir = path.join(projectPath, '.vscode');
    await fs.ensureDir(vscodeDir);
    // Create tasks.json for CodeContext commands
    const tasksPath = path.join(vscodeDir, 'tasks.json');
    const tasks = {
        version: '2.0.0',
        tasks: [
            {
                label: 'CodeContext: Show Status',
                type: 'shell',
                command: 'codecontext',
                args: ['status'],
                group: 'build',
                presentation: {
                    echo: true,
                    reveal: 'always',
                    focus: false,
                    panel: 'shared'
                },
                problemMatcher: []
            },
            {
                label: 'CodeContext: Scan Project',
                type: 'shell',
                command: 'codecontext',
                args: ['scan', '--deep'],
                group: 'build',
                presentation: {
                    echo: true,
                    reveal: 'always',
                    focus: false,
                    panel: 'shared'
                },
                problemMatcher: []
            },
            {
                label: 'CodeContext: Remember Current Context',
                type: 'shell',
                command: 'codecontext',
                args: ['remember', '${input:memoryContent}', '--context', '${file}:${lineNumber}'],
                group: 'build',
                presentation: {
                    echo: true,
                    reveal: 'always',
                    focus: false,
                    panel: 'shared'
                },
                problemMatcher: []
            },
            {
                label: 'CodeContext: Search Memories',
                type: 'shell',
                command: 'codecontext',
                args: ['recall', '${input:searchQuery}'],
                group: 'build',
                presentation: {
                    echo: true,
                    reveal: 'always',
                    focus: false,
                    panel: 'shared'
                },
                problemMatcher: []
            }
        ],
        inputs: [
            {
                id: 'memoryContent',
                description: 'What would you like to remember?',
                default: '',
                type: 'promptString'
            },
            {
                id: 'searchQuery',
                description: 'Search memories:',
                default: '',
                type: 'promptString'
            }
        ]
    };
    await fs.writeJson(tasksPath, tasks, { spaces: 2 });
    // Create settings.json with CodeContext integration
    const settingsPath = path.join(vscodeDir, 'settings.json');
    let settings = {};
    if (await fs.pathExists(settingsPath)) {
        settings = await fs.readJson(settingsPath);
    }
    // Add CodeContext-specific settings
    Object.assign(settings, {
        'terminal.integrated.env.linux': {
            'CODECONTEXT_PROJECT_PATH': projectPath
        },
        'terminal.integrated.env.osx': {
            'CODECONTEXT_PROJECT_PATH': projectPath
        },
        'terminal.integrated.env.windows': {
            'CODECONTEXT_PROJECT_PATH': projectPath
        },
        'files.watcherExclude': {
            '**/.codecontext/**': true
        }
    });
    await fs.writeJson(settingsPath, settings, { spaces: 2 });
    // Create keybindings for quick access
    const userDir = getUserVSCodeDir();
    if (userDir) {
        const keybindingsPath = path.join(userDir, 'keybindings.json');
        let keybindings = [];
        if (await fs.pathExists(keybindingsPath)) {
            const content = await fs.readFile(keybindingsPath, 'utf8');
            try {
                keybindings = JSON.parse(content);
            }
            catch {
                keybindings = [];
            }
        }
        // Add CodeContext keybindings if they don't exist
        const codecontextBindings = [
            {
                key: 'ctrl+shift+m ctrl+shift+s',
                command: 'workbench.action.tasks.runTask',
                args: 'CodeContext: Show Status'
            },
            {
                key: 'ctrl+shift+m ctrl+shift+r',
                command: 'workbench.action.tasks.runTask',
                args: 'CodeContext: Remember Current Context'
            },
            {
                key: 'ctrl+shift+m ctrl+shift+f',
                command: 'workbench.action.tasks.runTask',
                args: 'CodeContext: Search Memories'
            }
        ];
        for (const binding of codecontextBindings) {
            const exists = keybindings.some((k) => k.key === binding.key && k.command === binding.command);
            if (!exists) {
                keybindings.push(binding);
            }
        }
        await fs.writeJson(keybindingsPath, keybindings, { spaces: 2 });
    }
    // Create workspace snippet for CodeContext
    const snippetsDir = path.join(vscodeDir, 'snippets');
    await fs.ensureDir(snippetsDir);
    const snippetsPath = path.join(snippetsDir, 'codecontext.code-snippets');
    const snippets = {
        'Remember in CodeContext': {
            scope: 'javascript,typescript,python,go,rust,java',
            prefix: 'ccr',
            body: [
                '// CodeContext Memory: $1',
                '// Context: ${TM_FILENAME}:${TM_LINE_NUMBER}',
                '$0'
            ],
            description: 'Add a CodeContext memory note'
        },
        'CodeContext TODO': {
            scope: 'javascript,typescript,python,go,rust,java',
            prefix: 'cct',
            body: [
                '// TODO (CodeContext): $1',
                '// Priority: ${2|low,medium,high|}',
                '// Context: ${TM_FILENAME}:${TM_LINE_NUMBER}',
                '$0'
            ],
            description: 'Add a CodeContext TODO'
        }
    };
    await fs.writeJson(snippetsPath, snippets, { spaces: 2 });
    // Create launch configuration for debugging CodeContext CLI
    const launchPath = path.join(vscodeDir, 'launch.json');
    let launch = { version: '0.2.0', configurations: [] };
    if (await fs.pathExists(launchPath)) {
        launch = await fs.readJson(launchPath);
    }
    const codecontextConfig = {
        name: 'Debug CodeContext CLI',
        type: 'node',
        request: 'launch',
        program: '${workspaceFolder}/node_modules/.bin/codecontext',
        args: ['${input:codecontextCommand}'],
        console: 'integratedTerminal',
        env: {
            'NODE_ENV': 'development'
        }
    };
    const exists = launch.configurations.some((config) => config.name === codecontextConfig.name);
    if (!exists) {
        launch.configurations.push(codecontextConfig);
        await fs.writeJson(launchPath, launch, { spaces: 2 });
    }
}
function getUserVSCodeDir() {
    const platform = os.platform();
    const homeDir = os.homedir();
    let vscodeDir;
    switch (platform) {
        case 'win32':
            vscodeDir = path.join(homeDir, 'AppData', 'Roaming', 'Code', 'User');
            break;
        case 'darwin':
            vscodeDir = path.join(homeDir, 'Library', 'Application Support', 'Code', 'User');
            break;
        case 'linux':
            vscodeDir = path.join(homeDir, '.config', 'Code', 'User');
            break;
        default:
            return null;
    }
    return fs.existsSync(vscodeDir) ? vscodeDir : null;
}
//# sourceMappingURL=vscode-setup.js.map