"use strict";
/**
 * License Management Service
 * Handles the $99/month early adopter licensing model
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.licenseService = exports.LicenseService = void 0;
const fs = __importStar(require("fs-extra"));
const path = __importStar(require("path"));
const os = __importStar(require("os"));
const FirebaseService_1 = require("./FirebaseService");
class LicenseService {
    constructor() {
        this.licensePath = path.join(os.homedir(), '.codecontext', 'license.secure');
    }
    async purchaseLicense(email, paymentMethod = 'stripe') {
        // Check availability first
        const stats = await FirebaseService_1.firebaseService.checkLicenseAvailability();
        if (stats.remaining <= 0) {
            throw new Error(`
🚨 Early Adopter Licenses SOLD OUT!

The first 10,000 licenses at $99/month have been sold.
New price: $${stats.nextPrice}/month

Join the waitlist at https://codecontextpro.com/waitlist
      `);
        }
        console.log(`
🔥 EARLY ADOPTER OPPORTUNITY

💰 Current Price: $${stats.currentPrice}/month
📈 After ${stats.remaining} more sales: $${stats.nextPrice}/month  
⏰ ${stats.remaining} licenses remaining

🧠 What you get:
✅ Persistent AI Memory (Revolutionary!)
✅ Cloud Sync Across Devices  
✅ Multi-Project Support
✅ VS Code Integration
✅ Priority Support
✅ Locked-in $99/month FOREVER

This memory revolution is worth 100x the price.
    `);
        // In a real implementation, this would integrate with Stripe/PayPal
        // For now, simulate the purchase flow
        const licenseKey = await this.simulatePurchase(email, stats.currentPrice);
        console.log(`
🎉 LICENSE PURCHASED!

License Key: ${licenseKey}
Email: ${email}
Price: $${stats.currentPrice}/month (locked forever)

Run: codecontext activate ${licenseKey}
    `);
        return licenseKey;
    }
    async activateLicense(email, licenseKey) {
        try {
            const license = await FirebaseService_1.firebaseService.authenticate(email, licenseKey);
            // Store encrypted license locally
            await this.storeLicense(license);
            console.log(`
🚀 CODECONTEXT MEMORY PRO ACTIVATED!

Welcome to the AI memory revolution, ${email}!

Your AI assistant now has:
🧠 Persistent memory across ALL sessions
☁️ Cloud sync across all your devices  
📊 Advanced project analytics
🔧 VS Code integration
🎯 Priority support

Tier: ${license.tier.toUpperCase()}
Price: $${license.price}/month (locked forever)
Expires: ${license.expiresAt ? license.expiresAt.toLocaleDateString() : 'Never (subscription-based)'}

Start using: codecontext init
      `);
        }
        catch (error) {
            throw new Error(`License activation failed: ${error instanceof Error ? error.message : error}`);
        }
    }
    async getCurrentLicense() {
        try {
            if (!await fs.pathExists(this.licensePath)) {
                return null;
            }
            const encryptedLicense = await fs.readFile(this.licensePath, 'utf8');
            const license = this.decryptLicense(encryptedLicense);
            // Validate license is still active
            if (license.expiresAt && new Date() > new Date(license.expiresAt)) {
                await this.removeLicense();
                throw new Error('License expired. Please renew at https://codecontextpro.com');
            }
            return license;
        }
        catch (error) {
            return null;
        }
    }
    async validateFeatureAccess(feature) {
        const license = await this.getCurrentLicense();
        if (!license) {
            throw new Error(`
🔒 PREMIUM FEATURE REQUIRED

"${feature}" requires CodeContext Pro license.

🔥 Early Adopter Special: Only $99/month
📈 After 10,000 licenses sold: $199/month

This cognitive upgrade pays for itself in 1 day.
Purchase: https://codecontextpro.com/purchase

Compare:
❌ ChatGPT Pro: $20/month (no memory, no execution)  
❌ Claude Pro: $20/month (no memory, no execution)
❌ GitHub Copilot: $10/month (no memory, no execution)
✅ CodeContext Pro: $99/month (PERSISTENT MEMORY + EXECUTION!)

This is 10x more valuable than any other AI tool.
      `);
        }
        if (!license.features[feature]) {
            throw new Error(`
🔒 FEATURE NOT INCLUDED

"${feature}" is not included in your current plan.
Upgrade at https://codecontextpro.com/upgrade
      `);
        }
    }
    async showLicenseStatus() {
        const license = await this.getCurrentLicense();
        if (!license) {
            const stats = await FirebaseService_1.firebaseService.checkLicenseAvailability();
            console.log(`
🧠 CodeContext Pro - AI Memory Revolution

Status: UNLICENSED
Features Available: None

🔥 EARLY ADOPTER SPECIAL
💰 Price: $${stats.currentPrice}/month (${stats.remaining} left)
📈 Next Price: $${stats.nextPrice}/month  

What you're missing:
❌ Persistent AI memory across sessions
❌ Real-time code execution and verification
❌ Cloud sync across devices  
❌ Multi-project support
❌ Advanced analytics

This cognitive upgrade is worth $1000s/month in productivity.

Purchase: codecontext purchase your@email.com
      `);
            return;
        }
        console.log(`
🧠 CodeContext Pro - ACTIVATED

👤 User: ${license.email}
🎯 Tier: ${license.tier.toUpperCase()} 
💰 Price: $${license.price}/month (locked forever!)
📅 Expires: ${license.expiresAt ? license.expiresAt.toLocaleDateString() : 'Never (subscription-based)'}
📊 Projects: ${license.maxProjects === -1 ? 'Unlimited' : license.maxProjects}

✅ FEATURES UNLOCKED:
${license.features.persistentMemory ? '🧠' : '❌'} Persistent AI Memory
${license.features.executionEngine ? '⚡' : '❌'} Code Execution Engine  
${license.features.cloudSync ? '☁️' : '❌'} Cloud Sync
${license.features.multiProject ? '📁' : '❌'} Multi-Project Support
${license.features.prioritySupport ? '🎯' : '❌'} Priority Support

You're part of the AI cognitive revolution! 🚀
    `);
    }
    async simulatePurchase(email, price) {
        // In production, this would integrate with Stripe
        // For now, generate a mock license key
        const timestamp = Date.now();
        const hash = require('crypto').createHash('sha256')
            .update(`${email}-${timestamp}-codecontext-pro`)
            .digest('hex')
            .substring(0, 16)
            .toUpperCase();
        return `CCP-${hash.slice(0, 4)}-${hash.slice(4, 8)}-${hash.slice(8, 12)}-${hash.slice(12, 16)}`;
    }
    async storeLicense(license) {
        await fs.ensureDir(path.dirname(this.licensePath));
        const encrypted = this.encryptLicense(license);
        await fs.writeFile(this.licensePath, encrypted, { mode: 0o600 }); // Secure permissions
    }
    async removeLicense() {
        if (await fs.pathExists(this.licensePath)) {
            await fs.remove(this.licensePath);
        }
    }
    encryptLicense(license) {
        // Simple encryption for local storage
        const crypto = require('crypto');
        const key = crypto.scryptSync('codecontext-secret', 'salt', 32);
        const iv = crypto.randomBytes(16);
        const cipher = crypto.createCipheriv('aes-256-cbc', key, iv);
        let encrypted = cipher.update(JSON.stringify(license), 'utf8', 'hex');
        encrypted += cipher.final('hex');
        return iv.toString('hex') + ':' + encrypted;
    }
    decryptLicense(encrypted) {
        // Simple decryption for local storage
        const crypto = require('crypto');
        const key = crypto.scryptSync('codecontext-secret', 'salt', 32);
        const [ivHex, encryptedData] = encrypted.split(':');
        const iv = Buffer.from(ivHex, 'hex');
        const decipher = crypto.createDecipheriv('aes-256-cbc', key, iv);
        let decrypted = decipher.update(encryptedData, 'hex', 'utf8');
        decrypted += decipher.final('utf8');
        return JSON.parse(decrypted);
    }
}
exports.LicenseService = LicenseService;
exports.licenseService = new LicenseService();
//# sourceMappingURL=LicenseService.js.map